@@ -70,7 +70,28 @@ class ProjectIssueBoard(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ProjectIssueBoard.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id_: builtins.str,
+                *,
+                name: builtins.str,
+                project: builtins.str,
+                assignee_id: typing.Optional[jsii.Number] = None,
+                id: typing.Optional[builtins.str] = None,
+                labels: typing.Optional[typing.Sequence[builtins.str]] = None,
+                lists: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union[ProjectIssueBoardLists, typing.Dict[str, typing.Any]]]]] = None,
+                milestone_id: typing.Optional[jsii.Number] = None,
+                weight: typing.Optional[jsii.Number] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = ProjectIssueBoardConfig(
@@ -102,7 +123,11 @@ class ProjectIssueBoard(
         :param value: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ProjectIssueBoard.put_lists)
+            def stub(
+                value: typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union[ProjectIssueBoardLists, typing.Dict[str, typing.Any]]]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         return typing.cast(None, jsii.invoke(self, "putLists", [value]))
 
@@ -194,7 +219,9 @@ class ProjectIssueBoard(
     @assignee_id.setter
     def assignee_id(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ProjectIssueBoard, "assignee_id").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "assigneeId", value)
 
@@ -206,7 +233,9 @@ class ProjectIssueBoard(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ProjectIssueBoard, "id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -218,7 +247,9 @@ class ProjectIssueBoard(
     @labels.setter
     def labels(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ProjectIssueBoard, "labels").fset)
+            def stub(value: typing.List[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "labels", value)
 
@@ -230,7 +261,9 @@ class ProjectIssueBoard(
     @milestone_id.setter
     def milestone_id(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ProjectIssueBoard, "milestone_id").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "milestoneId", value)
 
@@ -242,7 +275,9 @@ class ProjectIssueBoard(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ProjectIssueBoard, "name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -254,7 +289,9 @@ class ProjectIssueBoard(
     @project.setter
     def project(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ProjectIssueBoard, "project").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "project", value)
 
@@ -266,7 +303,9 @@ class ProjectIssueBoard(
     @weight.setter
     def weight(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ProjectIssueBoard, "weight").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "weight", value)
 
@@ -332,7 +371,26 @@ class ProjectIssueBoardConfig(cdktf.TerraformMetaArguments):
         if isinstance(lifecycle, dict):
             lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(ProjectIssueBoardConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                name: builtins.str,
+                project: builtins.str,
+                assignee_id: typing.Optional[jsii.Number] = None,
+                id: typing.Optional[builtins.str] = None,
+                labels: typing.Optional[typing.Sequence[builtins.str]] = None,
+                lists: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union[ProjectIssueBoardLists, typing.Dict[str, typing.Any]]]]] = None,
+                milestone_id: typing.Optional[jsii.Number] = None,
+                weight: typing.Optional[jsii.Number] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -556,7 +614,15 @@ class ProjectIssueBoardLists:
         :param milestone_id: The ID of the milestone the list should be scoped to. Requires a GitLab EE license. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/gitlab/r/project_issue_board#milestone_id ProjectIssueBoard#milestone_id}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ProjectIssueBoardLists.__init__)
+            def stub(
+                *,
+                assignee_id: typing.Optional[jsii.Number] = None,
+                iteration_id: typing.Optional[jsii.Number] = None,
+                label_id: typing.Optional[jsii.Number] = None,
+                milestone_id: typing.Optional[jsii.Number] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument assignee_id", value=assignee_id, expected_type=type_hints["assignee_id"])
             check_type(argname="argument iteration_id", value=iteration_id, expected_type=type_hints["iteration_id"])
             check_type(argname="argument label_id", value=label_id, expected_type=type_hints["label_id"])
@@ -636,7 +702,13 @@ class ProjectIssueBoardListsList(
         :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ProjectIssueBoardListsList.__init__)
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+                wraps_set: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
@@ -648,7 +720,9 @@ class ProjectIssueBoardListsList(
         :param index: the index of the item to return.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ProjectIssueBoardListsList.get)
+            def stub(index: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument index", value=index, expected_type=type_hints["index"])
         return typing.cast("ProjectIssueBoardListsOutputReference", jsii.invoke(self, "get", [index]))
 
@@ -661,7 +735,9 @@ class ProjectIssueBoardListsList(
     @_terraform_attribute.setter
     def _terraform_attribute(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ProjectIssueBoardListsList, "_terraform_attribute").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformAttribute", value)
 
@@ -674,7 +750,9 @@ class ProjectIssueBoardListsList(
     @_terraform_resource.setter
     def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ProjectIssueBoardListsList, "_terraform_resource").fset)
+            def stub(value: cdktf.IInterpolatingParent) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformResource", value)
 
@@ -687,7 +765,9 @@ class ProjectIssueBoardListsList(
     @_wraps_set.setter
     def _wraps_set(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ProjectIssueBoardListsList, "_wraps_set").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "wrapsSet", value)
 
@@ -704,7 +784,11 @@ class ProjectIssueBoardListsList(
         value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ProjectIssueBoardLists]]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ProjectIssueBoardListsList, "internal_value").fset)
+            def stub(
+                value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ProjectIssueBoardLists]]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -728,7 +812,14 @@ class ProjectIssueBoardListsOutputReference(
         :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ProjectIssueBoardListsOutputReference.__init__)
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+                complex_object_index: jsii.Number,
+                complex_object_is_from_set: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
@@ -789,7 +880,9 @@ class ProjectIssueBoardListsOutputReference(
     @assignee_id.setter
     def assignee_id(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ProjectIssueBoardListsOutputReference, "assignee_id").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "assigneeId", value)
 
@@ -801,7 +894,9 @@ class ProjectIssueBoardListsOutputReference(
     @iteration_id.setter
     def iteration_id(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ProjectIssueBoardListsOutputReference, "iteration_id").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "iterationId", value)
 
@@ -813,7 +908,9 @@ class ProjectIssueBoardListsOutputReference(
     @label_id.setter
     def label_id(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ProjectIssueBoardListsOutputReference, "label_id").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "labelId", value)
 
@@ -825,7 +922,9 @@ class ProjectIssueBoardListsOutputReference(
     @milestone_id.setter
     def milestone_id(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ProjectIssueBoardListsOutputReference, "milestone_id").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "milestoneId", value)
 
@@ -842,7 +941,11 @@ class ProjectIssueBoardListsOutputReference(
         value: typing.Optional[typing.Union[ProjectIssueBoardLists, cdktf.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ProjectIssueBoardListsOutputReference, "internal_value").fset)
+            def stub(
+                value: typing.Optional[typing.Union[ProjectIssueBoardLists, cdktf.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
