@@ -64,7 +64,25 @@ class ProjectProtectedEnvironment(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ProjectProtectedEnvironment.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id_: builtins.str,
+                *,
+                deploy_access_levels: typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union[ProjectProtectedEnvironmentDeployAccessLevels, typing.Dict[str, typing.Any]]]],
+                environment: builtins.str,
+                project: builtins.str,
+                id: typing.Optional[builtins.str] = None,
+                required_approval_count: typing.Optional[jsii.Number] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = ProjectProtectedEnvironmentConfig(
@@ -93,7 +111,11 @@ class ProjectProtectedEnvironment(
         :param value: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ProjectProtectedEnvironment.put_deploy_access_levels)
+            def stub(
+                value: typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union[ProjectProtectedEnvironmentDeployAccessLevels, typing.Dict[str, typing.Any]]]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         return typing.cast(None, jsii.invoke(self, "putDeployAccessLevels", [value]))
 
@@ -156,7 +178,9 @@ class ProjectProtectedEnvironment(
     @environment.setter
     def environment(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ProjectProtectedEnvironment, "environment").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "environment", value)
 
@@ -168,7 +192,9 @@ class ProjectProtectedEnvironment(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ProjectProtectedEnvironment, "id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -180,7 +206,9 @@ class ProjectProtectedEnvironment(
     @project.setter
     def project(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ProjectProtectedEnvironment, "project").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "project", value)
 
@@ -192,7 +220,9 @@ class ProjectProtectedEnvironment(
     @required_approval_count.setter
     def required_approval_count(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ProjectProtectedEnvironment, "required_approval_count").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "requiredApprovalCount", value)
 
@@ -249,7 +279,23 @@ class ProjectProtectedEnvironmentConfig(cdktf.TerraformMetaArguments):
         if isinstance(lifecycle, dict):
             lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(ProjectProtectedEnvironmentConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                deploy_access_levels: typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union[ProjectProtectedEnvironmentDeployAccessLevels, typing.Dict[str, typing.Any]]]],
+                environment: builtins.str,
+                project: builtins.str,
+                id: typing.Optional[builtins.str] = None,
+                required_approval_count: typing.Optional[jsii.Number] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -432,7 +478,14 @@ class ProjectProtectedEnvironmentDeployAccessLevels:
         :param user_id: The ID of the user allowed to deploy to this protected environment. The user must be a member of the project. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/gitlab/r/project_protected_environment#user_id ProjectProtectedEnvironment#user_id}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ProjectProtectedEnvironmentDeployAccessLevels.__init__)
+            def stub(
+                *,
+                access_level: typing.Optional[builtins.str] = None,
+                group_id: typing.Optional[jsii.Number] = None,
+                user_id: typing.Optional[jsii.Number] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument access_level", value=access_level, expected_type=type_hints["access_level"])
             check_type(argname="argument group_id", value=group_id, expected_type=type_hints["group_id"])
             check_type(argname="argument user_id", value=user_id, expected_type=type_hints["user_id"])
@@ -504,7 +557,13 @@ class ProjectProtectedEnvironmentDeployAccessLevelsList(
         :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ProjectProtectedEnvironmentDeployAccessLevelsList.__init__)
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+                wraps_set: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
@@ -519,7 +578,9 @@ class ProjectProtectedEnvironmentDeployAccessLevelsList(
         :param index: the index of the item to return.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ProjectProtectedEnvironmentDeployAccessLevelsList.get)
+            def stub(index: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument index", value=index, expected_type=type_hints["index"])
         return typing.cast("ProjectProtectedEnvironmentDeployAccessLevelsOutputReference", jsii.invoke(self, "get", [index]))
 
@@ -532,7 +593,9 @@ class ProjectProtectedEnvironmentDeployAccessLevelsList(
     @_terraform_attribute.setter
     def _terraform_attribute(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ProjectProtectedEnvironmentDeployAccessLevelsList, "_terraform_attribute").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformAttribute", value)
 
@@ -545,7 +608,9 @@ class ProjectProtectedEnvironmentDeployAccessLevelsList(
     @_terraform_resource.setter
     def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ProjectProtectedEnvironmentDeployAccessLevelsList, "_terraform_resource").fset)
+            def stub(value: cdktf.IInterpolatingParent) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformResource", value)
 
@@ -558,7 +623,9 @@ class ProjectProtectedEnvironmentDeployAccessLevelsList(
     @_wraps_set.setter
     def _wraps_set(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ProjectProtectedEnvironmentDeployAccessLevelsList, "_wraps_set").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "wrapsSet", value)
 
@@ -575,7 +642,11 @@ class ProjectProtectedEnvironmentDeployAccessLevelsList(
         value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ProjectProtectedEnvironmentDeployAccessLevels]]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ProjectProtectedEnvironmentDeployAccessLevelsList, "internal_value").fset)
+            def stub(
+                value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[ProjectProtectedEnvironmentDeployAccessLevels]]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -599,7 +670,14 @@ class ProjectProtectedEnvironmentDeployAccessLevelsOutputReference(
         :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ProjectProtectedEnvironmentDeployAccessLevelsOutputReference.__init__)
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+                complex_object_index: jsii.Number,
+                complex_object_is_from_set: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
@@ -646,7 +724,9 @@ class ProjectProtectedEnvironmentDeployAccessLevelsOutputReference(
     @access_level.setter
     def access_level(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ProjectProtectedEnvironmentDeployAccessLevelsOutputReference, "access_level").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "accessLevel", value)
 
@@ -658,7 +738,9 @@ class ProjectProtectedEnvironmentDeployAccessLevelsOutputReference(
     @group_id.setter
     def group_id(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ProjectProtectedEnvironmentDeployAccessLevelsOutputReference, "group_id").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "groupId", value)
 
@@ -670,7 +752,9 @@ class ProjectProtectedEnvironmentDeployAccessLevelsOutputReference(
     @user_id.setter
     def user_id(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ProjectProtectedEnvironmentDeployAccessLevelsOutputReference, "user_id").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "userId", value)
 
@@ -687,7 +771,11 @@ class ProjectProtectedEnvironmentDeployAccessLevelsOutputReference(
         value: typing.Optional[typing.Union[ProjectProtectedEnvironmentDeployAccessLevels, cdktf.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ProjectProtectedEnvironmentDeployAccessLevelsOutputReference, "internal_value").fset)
+            def stub(
+                value: typing.Optional[typing.Union[ProjectProtectedEnvironmentDeployAccessLevels, cdktf.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
