@@ -76,7 +76,31 @@ class RepositoryFile(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RepositoryFile.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id_: builtins.str,
+                *,
+                branch: builtins.str,
+                commit_message: builtins.str,
+                content: builtins.str,
+                file_path: builtins.str,
+                project: builtins.str,
+                author_email: typing.Optional[builtins.str] = None,
+                author_name: typing.Optional[builtins.str] = None,
+                execute_filemode: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                id: typing.Optional[builtins.str] = None,
+                start_branch: typing.Optional[builtins.str] = None,
+                timeouts: typing.Optional[typing.Union[RepositoryFileTimeouts, typing.Dict[str, typing.Any]]] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = RepositoryFileConfig(
@@ -264,7 +288,9 @@ class RepositoryFile(
     @author_email.setter
     def author_email(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RepositoryFile, "author_email").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "authorEmail", value)
 
@@ -276,7 +302,9 @@ class RepositoryFile(
     @author_name.setter
     def author_name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RepositoryFile, "author_name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "authorName", value)
 
@@ -288,7 +316,9 @@ class RepositoryFile(
     @branch.setter
     def branch(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RepositoryFile, "branch").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "branch", value)
 
@@ -300,7 +330,9 @@ class RepositoryFile(
     @commit_message.setter
     def commit_message(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RepositoryFile, "commit_message").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "commitMessage", value)
 
@@ -312,7 +344,9 @@ class RepositoryFile(
     @content.setter
     def content(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RepositoryFile, "content").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "content", value)
 
@@ -327,7 +361,9 @@ class RepositoryFile(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RepositoryFile, "execute_filemode").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "executeFilemode", value)
 
@@ -339,7 +375,9 @@ class RepositoryFile(
     @file_path.setter
     def file_path(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RepositoryFile, "file_path").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "filePath", value)
 
@@ -351,7 +389,9 @@ class RepositoryFile(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RepositoryFile, "id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -363,7 +403,9 @@ class RepositoryFile(
     @project.setter
     def project(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RepositoryFile, "project").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "project", value)
 
@@ -375,7 +417,9 @@ class RepositoryFile(
     @start_branch.setter
     def start_branch(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RepositoryFile, "start_branch").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "startBranch", value)
 
@@ -452,7 +496,29 @@ class RepositoryFileConfig(cdktf.TerraformMetaArguments):
         if isinstance(timeouts, dict):
             timeouts = RepositoryFileTimeouts(**timeouts)
         if __debug__:
-            type_hints = typing.get_type_hints(RepositoryFileConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                branch: builtins.str,
+                commit_message: builtins.str,
+                content: builtins.str,
+                file_path: builtins.str,
+                project: builtins.str,
+                author_email: typing.Optional[builtins.str] = None,
+                author_name: typing.Optional[builtins.str] = None,
+                execute_filemode: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                id: typing.Optional[builtins.str] = None,
+                start_branch: typing.Optional[builtins.str] = None,
+                timeouts: typing.Optional[typing.Union[RepositoryFileTimeouts, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -707,7 +773,14 @@ class RepositoryFileTimeouts:
         :param update: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/gitlab/r/repository_file#update RepositoryFile#update}.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RepositoryFileTimeouts.__init__)
+            def stub(
+                *,
+                create: typing.Optional[builtins.str] = None,
+                delete: typing.Optional[builtins.str] = None,
+                update: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument create", value=create, expected_type=type_hints["create"])
             check_type(argname="argument delete", value=delete, expected_type=type_hints["delete"])
             check_type(argname="argument update", value=update, expected_type=type_hints["update"])
@@ -764,7 +837,12 @@ class RepositoryFileTimeoutsOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RepositoryFileTimeoutsOutputReference.__init__)
+            def stub(
+                terraform_resource: cdktf.IInterpolatingParent,
+                terraform_attribute: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -804,7 +882,9 @@ class RepositoryFileTimeoutsOutputReference(
     @create.setter
     def create(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RepositoryFileTimeoutsOutputReference, "create").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "create", value)
 
@@ -816,7 +896,9 @@ class RepositoryFileTimeoutsOutputReference(
     @delete.setter
     def delete(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RepositoryFileTimeoutsOutputReference, "delete").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "delete", value)
 
@@ -828,7 +910,9 @@ class RepositoryFileTimeoutsOutputReference(
     @update.setter
     def update(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RepositoryFileTimeoutsOutputReference, "update").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "update", value)
 
@@ -845,7 +929,11 @@ class RepositoryFileTimeoutsOutputReference(
         value: typing.Optional[typing.Union[RepositoryFileTimeouts, cdktf.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RepositoryFileTimeoutsOutputReference, "internal_value").fset)
+            def stub(
+                value: typing.Optional[typing.Union[RepositoryFileTimeouts, cdktf.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
