@@ -88,7 +88,37 @@ class ServiceJira(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ServiceJira.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id_: builtins.str,
+                *,
+                password: builtins.str,
+                project: builtins.str,
+                url: builtins.str,
+                username: builtins.str,
+                api_url: typing.Optional[builtins.str] = None,
+                comment_on_event_enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                commit_events: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                id: typing.Optional[builtins.str] = None,
+                issues_events: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                jira_issue_transition_id: typing.Optional[builtins.str] = None,
+                job_events: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                merge_requests_events: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                note_events: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                pipeline_events: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                project_key: typing.Optional[builtins.str] = None,
+                push_events: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                tag_push_events: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = ServiceJiraConfig(
@@ -312,7 +342,9 @@ class ServiceJira(
     @api_url.setter
     def api_url(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ServiceJira, "api_url").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "apiUrl", value)
 
@@ -329,7 +361,9 @@ class ServiceJira(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ServiceJira, "comment_on_event_enabled").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "commentOnEventEnabled", value)
 
@@ -344,7 +378,9 @@ class ServiceJira(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ServiceJira, "commit_events").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "commitEvents", value)
 
@@ -356,7 +392,9 @@ class ServiceJira(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ServiceJira, "id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -371,7 +409,9 @@ class ServiceJira(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ServiceJira, "issues_events").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "issuesEvents", value)
 
@@ -383,7 +423,9 @@ class ServiceJira(
     @jira_issue_transition_id.setter
     def jira_issue_transition_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ServiceJira, "jira_issue_transition_id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "jiraIssueTransitionId", value)
 
@@ -395,7 +437,9 @@ class ServiceJira(
     @job_events.setter
     def job_events(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ServiceJira, "job_events").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "jobEvents", value)
 
@@ -410,7 +454,9 @@ class ServiceJira(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ServiceJira, "merge_requests_events").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "mergeRequestsEvents", value)
 
@@ -425,7 +471,9 @@ class ServiceJira(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ServiceJira, "note_events").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "noteEvents", value)
 
@@ -437,7 +485,9 @@ class ServiceJira(
     @password.setter
     def password(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ServiceJira, "password").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "password", value)
 
@@ -452,7 +502,9 @@ class ServiceJira(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ServiceJira, "pipeline_events").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "pipelineEvents", value)
 
@@ -464,7 +516,9 @@ class ServiceJira(
     @project.setter
     def project(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ServiceJira, "project").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "project", value)
 
@@ -476,7 +530,9 @@ class ServiceJira(
     @project_key.setter
     def project_key(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ServiceJira, "project_key").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "projectKey", value)
 
@@ -491,7 +547,9 @@ class ServiceJira(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ServiceJira, "push_events").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "pushEvents", value)
 
@@ -506,7 +564,9 @@ class ServiceJira(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ServiceJira, "tag_push_events").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "tagPushEvents", value)
 
@@ -518,7 +578,9 @@ class ServiceJira(
     @url.setter
     def url(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ServiceJira, "url").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "url", value)
 
@@ -530,7 +592,9 @@ class ServiceJira(
     @username.setter
     def username(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ServiceJira, "username").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "username", value)
 
@@ -623,7 +687,35 @@ class ServiceJiraConfig(cdktf.TerraformMetaArguments):
         if isinstance(lifecycle, dict):
             lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(ServiceJiraConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                password: builtins.str,
+                project: builtins.str,
+                url: builtins.str,
+                username: builtins.str,
+                api_url: typing.Optional[builtins.str] = None,
+                comment_on_event_enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                commit_events: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                id: typing.Optional[builtins.str] = None,
+                issues_events: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                jira_issue_transition_id: typing.Optional[builtins.str] = None,
+                job_events: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                merge_requests_events: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                note_events: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                pipeline_events: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                project_key: typing.Optional[builtins.str] = None,
+                push_events: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                tag_push_events: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
