@@ -82,7 +82,34 @@ class User(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(User.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id_: builtins.str,
+                *,
+                email: builtins.str,
+                name: builtins.str,
+                username: builtins.str,
+                can_create_group: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                id: typing.Optional[builtins.str] = None,
+                is_admin: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                is_external: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                namespace_id: typing.Optional[jsii.Number] = None,
+                note: typing.Optional[builtins.str] = None,
+                password: typing.Optional[builtins.str] = None,
+                projects_limit: typing.Optional[jsii.Number] = None,
+                reset_password: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                skip_confirmation: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                state: typing.Optional[builtins.str] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = UserConfig(
@@ -255,7 +282,9 @@ class User(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(User, "can_create_group").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "canCreateGroup", value)
 
@@ -267,7 +296,9 @@ class User(
     @email.setter
     def email(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(User, "email").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "email", value)
 
@@ -279,7 +310,9 @@ class User(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(User, "id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -291,7 +324,9 @@ class User(
     @is_admin.setter
     def is_admin(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(User, "is_admin").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "isAdmin", value)
 
@@ -306,7 +341,9 @@ class User(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(User, "is_external").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "isExternal", value)
 
@@ -318,7 +355,9 @@ class User(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(User, "name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -330,7 +369,9 @@ class User(
     @namespace_id.setter
     def namespace_id(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(User, "namespace_id").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "namespaceId", value)
 
@@ -342,7 +383,9 @@ class User(
     @note.setter
     def note(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(User, "note").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "note", value)
 
@@ -354,7 +397,9 @@ class User(
     @password.setter
     def password(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(User, "password").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "password", value)
 
@@ -366,7 +411,9 @@ class User(
     @projects_limit.setter
     def projects_limit(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(User, "projects_limit").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "projectsLimit", value)
 
@@ -381,7 +428,9 @@ class User(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(User, "reset_password").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "resetPassword", value)
 
@@ -396,7 +445,9 @@ class User(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(User, "skip_confirmation").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "skipConfirmation", value)
 
@@ -408,7 +459,9 @@ class User(
     @state.setter
     def state(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(User, "state").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "state", value)
 
@@ -420,7 +473,9 @@ class User(
     @username.setter
     def username(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(User, "username").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "username", value)
 
@@ -504,7 +559,32 @@ class UserConfig(cdktf.TerraformMetaArguments):
         if isinstance(lifecycle, dict):
             lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(UserConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                email: builtins.str,
+                name: builtins.str,
+                username: builtins.str,
+                can_create_group: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                id: typing.Optional[builtins.str] = None,
+                is_admin: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                is_external: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                namespace_id: typing.Optional[jsii.Number] = None,
+                note: typing.Optional[builtins.str] = None,
+                password: typing.Optional[builtins.str] = None,
+                projects_limit: typing.Optional[jsii.Number] = None,
+                reset_password: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                skip_confirmation: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                state: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
